@@ -52,7 +52,7 @@ around run => sub ( $orig, $self ) {
 
         $self->generate_alien_cfg;
 
-        P->sys->system( $self->alien_indexer_bin_path, q[--config], $self->alien_cfg_path, q[--all] );
+        P->pm->run_check( $self->alien_indexer_bin_path, q[--config], $self->alien_cfg_path, q[--all] );
 
         exit 0;
     }
@@ -195,32 +195,32 @@ around app_build => sub ( $orig, $self ) {
             P->file->rmtree($re2_prefix);
             P->file->mkpath($re2_prefix);
 
-            P->sys->system(qq[wget -O - https://github.com/google/re2/archive/master.tar.gz | tar -C $re2_prefix --strip-components=1 -xzvf -]);
+            P->pm->run_check(qq[wget -O - https://github.com/google/re2/archive/master.tar.gz | tar -C $re2_prefix --strip-components=1 -xzvf -]);
 
             {
                 my $chdir_guard = P->file->chdir($re2_prefix) or die;
 
-                P->sys->system( 'make', '-j' . P->sys->cpus_num );
+                P->pm->run_check( 'make', '-j' . P->sys->cpus_num );
 
                 local $ENV{LDFLAGS} = '-pthread';
 
-                P->sys->system( 'make', 'test' );
+                P->pm->run_check( 'make', 'test' );
             }
 
             # sphinx
-            P->sys->system( q[wget -O - http://sphinxsearch.com/files/sphinx-] . $self->sphinx_ver . qq[-release.tar.gz | tar -C $ENV->{TEMP_DIR} -xzvf -] );
+            P->pm->run_check( q[wget -O - http://sphinxsearch.com/files/sphinx-] . $self->sphinx_ver . qq[-release.tar.gz | tar -C $ENV->{TEMP_DIR} -xzvf -] );
 
             # libstemmer
-            P->sys->system( qq[wget -O - http://snowball.tartarus.org/dist/libstemmer_c.tgz | tar -C $ENV->{TEMP_DIR}sphinx-] . $self->sphinx_ver . q[-release -xzvf -] );
+            P->pm->run_check( qq[wget -O - http://snowball.tartarus.org/dist/libstemmer_c.tgz | tar -C $ENV->{TEMP_DIR}sphinx-] . $self->sphinx_ver . q[-release -xzvf -] );
 
             {
                 my $chdir_guard = P->file->chdir( $ENV->{TEMP_DIR} . 'sphinx-' . $self->sphinx_ver . q[-release] ) or die;
 
-                P->sys->system( q[./configure], q[--prefix=] . $self->alien_dir, q[--with-mysql], q[--with-libstemmer], q[--with-libexpat], q[--with-iconv], q[--enable-id64], qq[--with-re2-includes=$re2_prefix] );
+                P->pm->run_check( q[./configure], q[--prefix=] . $self->alien_dir, q[--with-mysql], q[--with-libstemmer], q[--with-libexpat], q[--with-iconv], q[--enable-id64], qq[--with-re2-includes=$re2_prefix] );
 
-                P->sys->system( 'make', '-j' . P->sys->cpus_num );
+                P->pm->run_check( 'make', '-j' . P->sys->cpus_num );
 
-                P->sys->system( 'make', 'install' );
+                P->pm->run_check( 'make', 'install' );
 
                 return 1;
             }
